@@ -8,10 +8,7 @@ from .data import (
     _vaccinations_by_region_req,
     _vaccines_supplied_by_manufacturer_req,
     _vaccines_supplied_by_manufacturer_cum_req,
-    _vaccinations_by_age_range_90_dose1_req,
-    _vaccinations_by_age_range_90_dose2_req,
-    _vaccination_by_age_range_requests,
-    _vaccinations_pomurska_by_day_req,
+    _vaccination_by_age_group_requests,
     _vaccinations_by_region_by_day_requests,
     _vaccinations_municipalities_share_req,
     _vaccinations_timestamp_req,
@@ -23,7 +20,7 @@ from .parser import (
     _parse_vaccinations_by_region,
     _parse_vaccines_supplied_by_manufacturer,
     _parse_vaccines_supplied_by_manufacturer_cum,
-    _parse_vaccinations_by_age_range,
+    _parse_vaccinations_by_age_group,
     _parse_vaccinations_by_region_by_day,
     _parse_vaccinations_by_municipalities_share,
     _parse_vaccinations_timestamp,
@@ -36,9 +33,11 @@ from .types import (
     VaccinationByRegionRow,
     VaccinationByManufacturerRow,
     VaccinationDose,
-    VaccinationByAgeRange,
+    VaccinationByAgeGroup,
 )
 
+from .enums import Region, AgeGroup
+
 
 def _get_data(req, parse_response):
     resp = requests.post(_source, headers=_headers, json=req)
@@ -79,54 +78,42 @@ def vaccines_supplied_by_manufacturer_cumulative() -> "list[VaccinationByManufac
     )
 
 
-# by age range
-def vaccinations_by_age_range_90() -> "VaccinationByAgeRange":
-    def vaccinations_by_age_range_90_dose1() -> "list[VaccinationDose]":
-        return _get_data(
-            _vaccinations_by_age_range_90_dose1_req, _parse_vaccinations_by_age_range
-        )
-
-    def vaccinations_by_age_range_90_dose2() -> "list[VaccinationDose]":
-        return _get_data(
-            _vaccinations_by_age_range_90_dose2_req, _parse_vaccinations_by_age_range
-        )
-
-    dose1 = vaccinations_by_age_range_90_dose1()
-    dose2 = vaccinations_by_age_range_90_dose2()
-    return VaccinationByAgeRange(dose1=dose1, dose2=dose2)
-
-
-def vaccinations_by_age_range():
-    key_value = _vaccination_by_age_range_requests.items()
+# by age group
+def vaccinations_by_age_group(group: AgeGroup = None):
     obj = {}
-    for el in key_value:
-        key = el[0]
-        dose1_req = el[1][0]
-        dose2_req = el[1][1]
+    if group == None:
 
-        dose1 = _get_data(dose1_req, _parse_vaccinations_by_age_range)
-        dose2 = _get_data(dose2_req, _parse_vaccinations_by_age_range)
-        obj[key] = VaccinationByAgeRange(dose1=dose1, dose2=dose2)
+        key_value = _vaccination_by_age_group_requests.items()
+        for key, req_list in key_value:
+            dose1_req = req_list[0]
+            dose2_req = req_list[1]
+            dose1 = _get_data(dose1_req, _parse_vaccinations_by_age_group)
+            dose2 = _get_data(dose2_req, _parse_vaccinations_by_age_group)
+            obj[key] = VaccinationByAgeGroup(dose1=dose1, dose2=dose2)
 
+        return obj
+
+    dose1_req = _vaccination_by_age_group_requests[group][0]
+    dose2_req = _vaccination_by_age_group_requests[group][1]
+    dose1 = _get_data(dose1_req, _parse_vaccinations_by_age_group)
+    dose2 = _get_data(dose2_req, _parse_vaccinations_by_age_group)
+    obj[group] = VaccinationByAgeGroup(dose1=dose1, dose2=dose2)
     return obj
 
 
-# by individual region
-def vaccinations_pomurska_by_day() -> "list[VaccinationByDayRow]":
-    return _get_data(
-        _vaccinations_pomurska_by_day_req, _parse_vaccinations_by_region_by_day
-    )
-
-
-def vaccinations_by_region_by_day():
-    key_value = _vaccinations_by_region_by_day_requests.items()
+def vaccinations_by_region_by_day(region: Region = None):
     obj = {}
-    for el in key_value:
-        key = el[0]
-        doses_req = el[1][0]
+    if region == None:
+        key_value = _vaccinations_by_region_by_day_requests.items()
+        for key, req_list in key_value:
+            req = req_list[0]
+            doses = _get_data(req, _parse_vaccinations_by_region_by_day)
+            obj[key] = doses
+        return obj
 
-        doses = _get_data(doses_req, _parse_vaccinations_by_region_by_day)
-        obj[key] = doses
+    req = _vaccinations_by_region_by_day_requests[region][0]
+    doses = _get_data(req, _parse_vaccinations_by_region_by_day)
+    obj[region] = doses
 
     return obj
 
