@@ -1,4 +1,5 @@
 import json
+from .enums import Region, AgeGroup
 
 _source = "https://wabi-west-europe-e-primary-api.analysis.windows.net/public/reports/querydata?synchronous=true"
 
@@ -82,7 +83,7 @@ def _create_req(commands, cache_key=False):
 
 
 # AGE RANGE (AGE GROUP)
-def _get_default_by_age_range_command():
+def _get_default_by_age_group_command():
     return {
         "SemanticQueryDataShapeCommand": {
             "Query": {
@@ -201,61 +202,40 @@ def _get_default_by_age_range_command():
     }
 
 
-def _get_by_age_range_first_condition_values(range="'90+'", dose="1L"):
+def _get_by_age_group_first_condition_values(group="'90+'", dose="1L"):
     return [
-        {"Literal": {"Value": range}},
+        {"Literal": {"Value": group}},
         {"Literal": {"Value": dose}},
     ]
 
 
-def _create_by_age_range_command(range="'90+'", dose="1L"):
-    values = _get_by_age_range_first_condition_values(range, dose)
-    command = _get_default_by_age_range_command()
+def _create_by_age_group_command(group="'90+'", dose="1L"):
+    values = _get_by_age_group_first_condition_values(group, dose)
+    command = _get_default_by_age_group_command()
     command["SemanticQueryDataShapeCommand"]["Query"]["Where"][0]["Condition"]["In"][
         "Values"
     ].append(values)
     return command
 
 
-age_ranges = [
-    "'0-17'",
-    "'18-24'",
-    "'25-29'",
-    "'30-34'",
-    "'35-39'",
-    "'40-44'",
-    "'45-49'",
-    "'50-54'",
-    "'55-59'",
-    "'60-64'",
-    "'65-69'",
-    "'70-74'",
-    "'75-79'",
-    "'80-84'",
-    "'85-90'",
-    "'90+'",
-]
-
-
-def _create_by_age_range_commands():
+def _create_by_age_group_commands():
     obj = {}
-    for el in age_ranges:
-        dose1_command = _create_by_age_range_command(el, "1L")
-        dose2_command = _create_by_age_range_command(el, "2L")
-        key = el.replace("'", "")
-        obj[key] = [dose1_command, dose2_command]
+    for el in AgeGroup:
+        dose1_command = _create_by_age_group_command(el.value, "1L")
+        dose2_command = _create_by_age_group_command(el.value, "2L")
+        obj[el] = [dose1_command, dose2_command]
 
     return obj
 
 
-def _create_by_age_range_requests():
-    commands = _create_by_age_range_commands()
+def _create_by_age_group_requests():
+    commands = _create_by_age_group_commands()
     key_value = commands.items()
     obj = {}
     for el in key_value:
         key = el[0]
         _commands = el[1]
-        range_requests = []
+        group_requests = []
         dose1_req = _create_req([_commands[0]])
         dose2_req = _create_req([_commands[1]])
         obj[key] = [dose1_req, dose2_req]
@@ -367,28 +347,11 @@ def _create_by_region_by_day_command(region):
     return command
 
 
-regions = [
-    "'Goriška'",
-    "'Zasavska'",
-    "'Koroška'",
-    "'Gorenjska'",
-    "'Osrednjeslovenska'",
-    "'Posavska'",
-    "'Podravska'",
-    "'Pomurska'",
-    "'Savinjska'",
-    "'Jugovzhodna Slovenija'",
-    "'Primorsko-notranjska'",
-    "'Obalno-kraška'",
-]
-
-
 def _create_by_region_by_day_commands():
     obj = {}
-    for el in regions:
-        doses_command = _create_by_region_by_day_command(el)
-        key = el.replace("'", "")
-        obj[key] = [doses_command]
+    for el in Region:
+        doses_command = _create_by_region_by_day_command(el.value)
+        obj[el] = [doses_command]
 
     return obj
 
@@ -400,7 +363,7 @@ def _create_by_region_by_day_requests():
     for el in key_value:
         key = el[0]
         _commands = el[1]
-        range_requests = []
+        group_requests = []
         doses_req = _create_req([_commands[0]])
         obj[key] = [doses_req]
 
@@ -1008,8 +971,8 @@ _vaccination_supplied_by_manufacturer_cum_command = {
             "Version": 2,
             "From": [
                 {"Name": "c1", "Entity": "Calendar", "Type": 0},
-                {"Name": "v", "Entity": "Vezno_Vrsta_cepiva", "Type": 0},
                 {"Name": "n", "Entity": "xls_NIJZ_Odmerki", "Type": 0},
+                {"Name": "s", "Entity": "Sifrant_Cepivo", "Type": 0},
             ],
             "Select": [
                 {
@@ -1019,13 +982,6 @@ _vaccination_supplied_by_manufacturer_cum_command = {
                     },
                     "Name": "Calendar.Date",
                 },
-                {
-                    "Column": {
-                        "Expression": {"SourceRef": {"Source": "v"}},
-                        "Property": "Vrsta_cepiva",
-                    },
-                    "Name": "Vezno_Vrsta_cepiva.Vrsta_cepiva",
-                },
                 {
                     "Measure": {
                         "Expression": {"SourceRef": {"Source": "n"}},
@@ -1033,6 +989,13 @@ _vaccination_supplied_by_manufacturer_cum_command = {
                     },
                     "Name": "NIJZ_Odmerki.Tekoča vsota za mero odmerki* v polju Date",
                 },
+                {
+                    "Column": {
+                        "Expression": {"SourceRef": {"Source": "s"}},
+                        "Property": "Cepivo_Ime",
+                    },
+                    "Name": "Sifrant_Cepivo.Cepivo_Ime",
+                },
             ],
             "Where": [
                 {
@@ -1085,8 +1048,8 @@ _vaccination_supplied_by_manufacturer_cum_command = {
             ],
         },
         "Binding": {
-            "Primary": {"Groupings": [{"Projections": [0, 2]}]},
-            "Secondary": {"Groupings": [{"Projections": [1]}]},
+            "Primary": {"Groupings": [{"Projections": [0, 1]}]},
+            "Secondary": {"Groupings": [{"Projections": [2]}]},
             "DataReduction": {
                 "DataVolume": 4,
                 "Intersection": {"BinnedLineSample": {}},
@@ -1097,11 +1060,6 @@ _vaccination_supplied_by_manufacturer_cum_command = {
     }
 }
 
-_vaccinations_by_age_90_dose1_command = _create_by_age_range_command("'90+'", "1L")
-_vaccinations_by_age_90_dose2_command = _create_by_age_range_command("'90+'", "2L")
-
-_vaccinations_pomurska_by_day_command = _create_by_region_by_day_command("'Pomurska'")
-
 _vaccinations_by_municipalities_share_command = {
     "SemanticQueryDataShapeCommand": {
         "Query": {
@@ -1112,13 +1070,6 @@ _vaccinations_by_municipalities_share_command = {
                 {"Name": "c", "Entity": "Calendar", "Type": 0},
             ],
             "Select": [
-                {
-                    "Measure": {
-                        "Expression": {"SourceRef": {"Source": "e"}},
-                        "Property": "Odst_2_Odmerek",
-                    },
-                    "Name": "eRCO_podatki_obcine.Odst_DrugiOdmerek",
-                },
                 {
                     "Column": {
                         "Expression": {"SourceRef": {"Source": "s"}},
@@ -1129,7 +1080,7 @@ _vaccinations_by_municipalities_share_command = {
                 {
                     "Measure": {
                         "Expression": {"SourceRef": {"Source": "e"}},
-                        "Property": "Odst_1_Odmerek",
+                        "Property": "Odst_Obcina_1_1",
                     },
                     "Name": "eRCO_podatki_obcine.Odst_PrviOdmerek",
                 },
@@ -1145,6 +1096,13 @@ _vaccinations_by_municipalities_share_command = {
                     },
                     "Name": "CountNonNull(SURS_obcine.PopulacijaObcina)",
                 },
+                {
+                    "Measure": {
+                        "Expression": {"SourceRef": {"Source": "e"}},
+                        "Property": "Odst_Obcina_2",
+                    },
+                    "Name": "eRCO_podatki_obcine_pop.Odst_Obcina_2",
+                },
             ],
             "Where": [
                 {
@@ -1198,7 +1156,7 @@ _vaccinations_by_municipalities_share_command = {
                     "Expression": {
                         "Measure": {
                             "Expression": {"SourceRef": {"Source": "e"}},
-                            "Property": "Odst_2_Odmerek",
+                            "Property": "Odst_Obcina_2",
                         }
                     },
                 }
@@ -1207,8 +1165,8 @@ _vaccinations_by_municipalities_share_command = {
         "Binding": {
             "Primary": {"Groupings": [{"Projections": [0, 1, 2, 3]}]},
             "DataReduction": {"DataVolume": 4, "Primary": {"Top": {}}},
-            "Aggregates": [{"Select": 0, "Aggregations": [{"Min": {}}, {"Max": {}}]}],
-            "SuppressedJoinPredicates": [2, 3],
+            "Aggregates": [{"Select": 3, "Aggregations": [{"Min": {}}, {"Max": {}}]}],
+            "SuppressedJoinPredicates": [1, 2],
             "Version": 1,
         },
         "ExecutionMetricsKind": 1,
@@ -1234,16 +1192,7 @@ _vaccines_supplied_by_manufacturer_cum_req = _create_req(
     [_vaccination_supplied_by_manufacturer_cum_command]
 )
 
-_vaccinations_by_age_range_90_dose1_req = _create_req(
-    [_vaccinations_by_age_90_dose1_command]
-)
-_vaccinations_by_age_range_90_dose2_req = _create_req(
-    [_vaccinations_by_age_90_dose2_command]
-)
-
-_vaccination_by_age_range_requests = _create_by_age_range_requests()
-
-_vaccinations_pomurska_by_day_req = _create_req([_vaccinations_pomurska_by_day_command])
+_vaccination_by_age_group_requests = _create_by_age_group_requests()
 
 _vaccinations_by_region_by_day_requests = _create_by_region_by_day_requests()
 
