@@ -7,7 +7,7 @@ from .types import (
     VaccinationByRegionRow,
     VaccinationByManufacturerRow,
     VaccinationDose,
-    VaccinationByAgeRange,
+    VaccinationByAgeGroup,
     VaccinationMunShare,
 )
 
@@ -199,6 +199,12 @@ def _parse_vaccines_supplied_by_manufacturer(
 def _parse_vaccines_supplied_by_manufacturer_cum(
     data,
 ) -> "list[VaccinationByManufacturerRow]":
+    if "DS" not in data["results"][0]["result"]["data"]["dsr"]:
+        error = data["results"][0]["result"]["data"]["dsr"]["DataShapes"][0][
+            "odata.error"
+        ]
+        print(error)
+        raise Exception("Something went wrong!")
     resp = data["results"][0]["result"]["data"]["dsr"]["DS"][0]["PH"][0]["DM0"]
     parsed_data = []
 
@@ -211,39 +217,26 @@ def _parse_vaccines_supplied_by_manufacturer_cum(
         az = None
         janssen = None
 
-        if len(elements) == 1:
-            el = elements[0]
+        for el in elements:
             if el.get("I", None) == 1:
-                moderna = int(el["M0"])
+                janssen = int(el["M0"])
             elif el.get("I", None) == 2:
+                moderna = int(el["M0"])
+            elif el.get("I", None) == 3:
                 pfizer = int(el["M0"])
             else:
                 az = int(el["M0"])
 
-        # ? what if some other combination
-        if len(elements) == 2:
-            az = elements[0]["M0"]
-            moderna = elements[1]["M0"]
-
-        if len(elements) == 3:
-            az = round(elements[0]["M0"])
-            moderna = round(elements[1]["M0"])
-            pfizer = round(elements[2]["M0"])
-
         parsed_data.append(
             VaccinationByManufacturerRow(
-                date=date,
-                pfizer=pfizer,
-                moderna=moderna,
-                az=az,
-                janssen=janssen,
+                date=date, pfizer=pfizer, moderna=moderna, az=az, janssen=janssen
             )
         )
 
     return parsed_data
 
 
-def _parse_vaccinations_by_age_range(data) -> "list[VaccinationDose]":
+def _parse_vaccinations_by_age_group(data) -> "list[VaccinationDose]":
     resp = data["results"][0]["result"]["data"]["dsr"]["DS"][0]["PH"][0]["DM0"]
     parsed_data = []
 
@@ -266,34 +259,6 @@ def _parse_vaccinations_by_age_range(data) -> "list[VaccinationDose]":
     return parsed_data
 
 
-# resp error example
-_resp_error = {
-    "DataShapes": [
-        {
-            "odata.error": {
-                "code": "InvalidOrMalformedSemanticQueryDefinition",
-                "source": "PowerBI",
-                "message": {
-                    "lang": "en-US",
-                    "value": "Encountered invalid QueryYearConstantExpression. Failed to parse type encoded string",
-                },
-                "azure:values": [
-                    {"timestamp": "2021-04-11T12:13:03.0228291Z"},
-                    {
-                        "additionalMessages": [
-                            {
-                                "Code": "InvalidOrMalformedSemanticQueryDefinition",
-                                "Severity": "Error",
-                                "Message": "Encountered invalid QueryYearConstantExpression. Failed to parse type encoded string",
-                            }
-                        ]
-                    },
-                ],
-            }
-        }
-    ]
-}
-
 # ? most likely we can refactor _parse_vaccinations_by_day
 def _parse_vaccinations_by_region_by_day(data):
 
@@ -301,7 +266,6 @@ def _parse_vaccinations_by_region_by_day(data):
         error = data["results"][0]["result"]["data"]["dsr"]["DataShapes"][0][
             "odata.error"
         ]
-        # it happens when region name passed to _get_default_by_region_by_day_condition_values func is misspelled or not wrapped in single quotes
         # ? raise exception or return error obj
         return error
 
@@ -341,11 +305,18 @@ def _parse_vaccinations_by_region_by_day(data):
 
 
 def _parse_vaccinations_by_municipalities_share(data) -> "list[VaccinationMunShare]":
+    if "DS" not in data["results"][0]["result"]["data"]["dsr"]:
+        error = data["results"][0]["result"]["data"]["dsr"]["DataShapes"][0][
+            "odata.error"
+        ]
+        print(error)
+        raise Exception("Something went wrong!")
     resp = data["results"][0]["result"]["data"]["dsr"]["DS"][0]["PH"][0]["DM0"]
     parsed_data = []
 
     for el in resp:
-        name, share2, share1, population = el["C"]
+        name, share2, population, share1 = el["C"]
+        print(name, share2, population, share1, sep="\t")
         dose1 = round(int(population) * float(share1))
         dose2 = round(int(population) * float(share2))
         parsed_data.append(
